#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VCardIdentification:
    def __init__(self):
        self.formatedName = None
        self.name = None
        self.nickname = None
        self.photo = None
        self.photoBinary = None
        self.birthday = None
        self.anniversary = None
        self.gender = None
        pass


class __VCardIdentificationSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VCardIdentification()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.VCardIdentificationFormatedName import VCardIdentificationFormatedName
        from netbluemind.addressbook.api.VCardIdentificationFormatedName import __VCardIdentificationFormatedNameSerDer__
        formatedNameValue = value['formatedName']
        instance.formatedName = __VCardIdentificationFormatedNameSerDer__().parse(formatedNameValue)
        from netbluemind.addressbook.api.VCardIdentificationName import VCardIdentificationName
        from netbluemind.addressbook.api.VCardIdentificationName import __VCardIdentificationNameSerDer__
        nameValue = value['name']
        instance.name = __VCardIdentificationNameSerDer__().parse(nameValue)
        from netbluemind.addressbook.api.VCardIdentificationNickname import VCardIdentificationNickname
        from netbluemind.addressbook.api.VCardIdentificationNickname import __VCardIdentificationNicknameSerDer__
        nicknameValue = value['nickname']
        instance.nickname = __VCardIdentificationNicknameSerDer__().parse(nicknameValue)
        photoValue = value['photo']
        instance.photo = serder.BOOLEAN.parse(photoValue)
        photoBinaryValue = value['photoBinary']
        instance.photoBinary = serder.ByteArraySerDer.parse(photoBinaryValue)
        birthdayValue = value['birthday']
        instance.birthday = serder.DATE.parse(birthdayValue)
        anniversaryValue = value['anniversary']
        instance.anniversary = serder.DATE.parse(anniversaryValue)
        from netbluemind.addressbook.api.VCardIdentificationGender import VCardIdentificationGender
        from netbluemind.addressbook.api.VCardIdentificationGender import __VCardIdentificationGenderSerDer__
        genderValue = value['gender']
        instance.gender = __VCardIdentificationGenderSerDer__().parse(genderValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.VCardIdentificationFormatedName import VCardIdentificationFormatedName
        from netbluemind.addressbook.api.VCardIdentificationFormatedName import __VCardIdentificationFormatedNameSerDer__
        formatedNameValue = value.formatedName
        instance["formatedName"] = __VCardIdentificationFormatedNameSerDer__().encode(
            formatedNameValue)
        from netbluemind.addressbook.api.VCardIdentificationName import VCardIdentificationName
        from netbluemind.addressbook.api.VCardIdentificationName import __VCardIdentificationNameSerDer__
        nameValue = value.name
        instance["name"] = __VCardIdentificationNameSerDer__().encode(nameValue)
        from netbluemind.addressbook.api.VCardIdentificationNickname import VCardIdentificationNickname
        from netbluemind.addressbook.api.VCardIdentificationNickname import __VCardIdentificationNicknameSerDer__
        nicknameValue = value.nickname
        instance["nickname"] = __VCardIdentificationNicknameSerDer__().encode(
            nicknameValue)
        photoValue = value.photo
        instance["photo"] = serder.BOOLEAN.encode(photoValue)
        photoBinaryValue = value.photoBinary
        instance["photoBinary"] = serder.ByteArraySerDer.encode(
            photoBinaryValue)
        birthdayValue = value.birthday
        instance["birthday"] = serder.DATE.encode(birthdayValue)
        anniversaryValue = value.anniversary
        instance["anniversary"] = serder.DATE.encode(anniversaryValue)
        from netbluemind.addressbook.api.VCardIdentificationGender import VCardIdentificationGender
        from netbluemind.addressbook.api.VCardIdentificationGender import __VCardIdentificationGenderSerDer__
        genderValue = value.gender
        instance["gender"] = __VCardIdentificationGenderSerDer__().encode(
            genderValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class DirEntryQuery:
    def __init__(self):
        self.order = None
        self.nameFilter = None
        self.hiddenFilter = None
        self.emailFilter = None
        self.nameOrEmailFilter = None
        self.stateFilter = None
        self.systemFilter = None
        self.kindsFilter = None
        self.entries = None
        self.orgUnitIds = None
        self.accountTypeFilter = None
        self.from_ = None
        self.size = None
        self.entryUidFilter = None
        self.onlyManagable = None
        self.dataLocation = None
        pass


class __DirEntryQuerySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = DirEntryQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.directory.api.DirEntryQueryOrder import DirEntryQueryOrder
        from netbluemind.directory.api.DirEntryQueryOrder import __DirEntryQueryOrderSerDer__
        orderValue = value['order']
        instance.order = __DirEntryQueryOrderSerDer__().parse(orderValue)
        nameFilterValue = value['nameFilter']
        instance.nameFilter = serder.STRING.parse(nameFilterValue)
        hiddenFilterValue = value['hiddenFilter']
        instance.hiddenFilter = serder.BOOLEAN.parse(hiddenFilterValue)
        emailFilterValue = value['emailFilter']
        instance.emailFilter = serder.STRING.parse(emailFilterValue)
        nameOrEmailFilterValue = value['nameOrEmailFilter']
        instance.nameOrEmailFilter = serder.STRING.parse(
            nameOrEmailFilterValue)
        from netbluemind.directory.api.DirEntryQueryStateFilter import DirEntryQueryStateFilter
        from netbluemind.directory.api.DirEntryQueryStateFilter import __DirEntryQueryStateFilterSerDer__
        stateFilterValue = value['stateFilter']
        instance.stateFilter = __DirEntryQueryStateFilterSerDer__().parse(stateFilterValue)
        systemFilterValue = value['systemFilter']
        instance.systemFilter = serder.BOOLEAN.parse(systemFilterValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        kindsFilterValue = value['kindsFilter']
        instance.kindsFilter = serder.ListSerDer(
            __BaseDirEntryKindSerDer__()).parse(kindsFilterValue)
        entriesValue = value['entries']
        instance.entries = serder.ListSerDer(serder.STRING).parse(entriesValue)
        orgUnitIdsValue = value['orgUnitIds']
        instance.orgUnitIds = serder.ListSerDer(
            serder.LONG).parse(orgUnitIdsValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeFilterValue = value['accountTypeFilter']
        instance.accountTypeFilter = __BaseDirEntryAccountTypeSerDer__().parse(
            accountTypeFilterValue)
        from_Value = value['from']
        instance.from_ = serder.INT.parse(from_Value)
        sizeValue = value['size']
        instance.size = serder.INT.parse(sizeValue)
        entryUidFilterValue = value['entryUidFilter']
        instance.entryUidFilter = serder.ListSerDer(
            serder.STRING).parse(entryUidFilterValue)
        onlyManagableValue = value['onlyManagable']
        instance.onlyManagable = serder.BOOLEAN.parse(onlyManagableValue)
        dataLocationValue = value['dataLocation']
        instance.dataLocation = serder.STRING.parse(dataLocationValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.directory.api.DirEntryQueryOrder import DirEntryQueryOrder
        from netbluemind.directory.api.DirEntryQueryOrder import __DirEntryQueryOrderSerDer__
        orderValue = value.order
        instance["order"] = __DirEntryQueryOrderSerDer__().encode(orderValue)
        nameFilterValue = value.nameFilter
        instance["nameFilter"] = serder.STRING.encode(nameFilterValue)
        hiddenFilterValue = value.hiddenFilter
        instance["hiddenFilter"] = serder.BOOLEAN.encode(hiddenFilterValue)
        emailFilterValue = value.emailFilter
        instance["emailFilter"] = serder.STRING.encode(emailFilterValue)
        nameOrEmailFilterValue = value.nameOrEmailFilter
        instance["nameOrEmailFilter"] = serder.STRING.encode(
            nameOrEmailFilterValue)
        from netbluemind.directory.api.DirEntryQueryStateFilter import DirEntryQueryStateFilter
        from netbluemind.directory.api.DirEntryQueryStateFilter import __DirEntryQueryStateFilterSerDer__
        stateFilterValue = value.stateFilter
        instance["stateFilter"] = __DirEntryQueryStateFilterSerDer__().encode(
            stateFilterValue)
        systemFilterValue = value.systemFilter
        instance["systemFilter"] = serder.BOOLEAN.encode(systemFilterValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        kindsFilterValue = value.kindsFilter
        instance["kindsFilter"] = serder.ListSerDer(
            __BaseDirEntryKindSerDer__()).encode(kindsFilterValue)
        entriesValue = value.entries
        instance["entries"] = serder.ListSerDer(
            serder.STRING).encode(entriesValue)
        orgUnitIdsValue = value.orgUnitIds
        instance["orgUnitIds"] = serder.ListSerDer(
            serder.LONG).encode(orgUnitIdsValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeFilterValue = value.accountTypeFilter
        instance["accountTypeFilter"] = __BaseDirEntryAccountTypeSerDer__().encode(
            accountTypeFilterValue)
        from_Value = value.from_
        instance["from"] = serder.INT.encode(from_Value)
        sizeValue = value.size
        instance["size"] = serder.INT.encode(sizeValue)
        entryUidFilterValue = value.entryUidFilter
        instance["entryUidFilter"] = serder.ListSerDer(
            serder.STRING).encode(entryUidFilterValue)
        onlyManagableValue = value.onlyManagable
        instance["onlyManagable"] = serder.BOOLEAN.encode(onlyManagableValue)
        dataLocationValue = value.dataLocation
        instance["dataLocation"] = serder.STRING.encode(dataLocationValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class BaseContainerDescriptor:
    def __init__(self):
        self.uid = None
        self.name = None
        self.owner = None
        self.type = None
        self.defaultContainer = None
        self.readOnly = None
        self.domainUid = None
        self.ownerDisplayname = None
        self.ownerDirEntryPath = None
        self.settings = None
        self.deleted = None
        self.datalocation = None
        pass


class __BaseContainerDescriptorSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = BaseContainerDescriptor()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        uidValue = value['uid']
        instance.uid = serder.STRING.parse(uidValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        ownerValue = value['owner']
        instance.owner = serder.STRING.parse(ownerValue)
        typeValue = value['type']
        instance.type = serder.STRING.parse(typeValue)
        defaultContainerValue = value['defaultContainer']
        instance.defaultContainer = serder.BOOLEAN.parse(defaultContainerValue)
        readOnlyValue = value['readOnly']
        instance.readOnly = serder.BOOLEAN.parse(readOnlyValue)
        domainUidValue = value['domainUid']
        instance.domainUid = serder.STRING.parse(domainUidValue)
        ownerDisplaynameValue = value['ownerDisplayname']
        instance.ownerDisplayname = serder.STRING.parse(ownerDisplaynameValue)
        ownerDirEntryPathValue = value['ownerDirEntryPath']
        instance.ownerDirEntryPath = serder.STRING.parse(
            ownerDirEntryPathValue)
        settingsValue = value['settings']
        instance.settings = serder.MapSerDer(
            serder.STRING).parse(settingsValue)
        deletedValue = value['deleted']
        instance.deleted = serder.BOOLEAN.parse(deletedValue)
        datalocationValue = value['datalocation']
        instance.datalocation = serder.STRING.parse(datalocationValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        uidValue = value.uid
        instance["uid"] = serder.STRING.encode(uidValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        ownerValue = value.owner
        instance["owner"] = serder.STRING.encode(ownerValue)
        typeValue = value.type
        instance["type"] = serder.STRING.encode(typeValue)
        defaultContainerValue = value.defaultContainer
        instance["defaultContainer"] = serder.BOOLEAN.encode(
            defaultContainerValue)
        readOnlyValue = value.readOnly
        instance["readOnly"] = serder.BOOLEAN.encode(readOnlyValue)
        domainUidValue = value.domainUid
        instance["domainUid"] = serder.STRING.encode(domainUidValue)
        ownerDisplaynameValue = value.ownerDisplayname
        instance["ownerDisplayname"] = serder.STRING.encode(
            ownerDisplaynameValue)
        ownerDirEntryPathValue = value.ownerDirEntryPath
        instance["ownerDirEntryPath"] = serder.STRING.encode(
            ownerDirEntryPathValue)
        settingsValue = value.settings
        instance["settings"] = serder.MapSerDer(
            serder.STRING).encode(settingsValue)
        deletedValue = value.deleted
        instance["deleted"] = serder.BOOLEAN.encode(deletedValue)
        datalocationValue = value.datalocation
        instance["datalocation"] = serder.STRING.encode(datalocationValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IOrgUnits_VERSION = "4.1.65141"


class IOrgUnits(BaseEndpoint):
    def __init__(self, apiKey, url, domain):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/directory/_ou/{domain}'
        self.domain_ = domain
        self.base = self.base.replace('{domain}', domain)

    def getAdministratorRoles(self, uid, dirUid, groups):
        postUri = "/{uid}/{dirUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        postUri = postUri.replace("{dirUid}", dirUid)
        __data__ = serder.ListSerDer(serder.STRING).encode(groups)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)

    def setAdministratorRoles(self, uid, dirUid, roles):
        postUri = "/{uid}/{dirUid}/_set"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        postUri = postUri.replace("{dirUid}", dirUid)
        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def update(self, uid, value):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        __data__ = __OrgUnitSerDer__().encode(value)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def removeAdministrator(self, administrator):
        postUri = "/_deleteadmin"
        __data__ = None
        __encoded__ = None
        queryParams = {'administrator': administrator}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getAdministrators(self, uid):
        postUri = "/{uid}/_administrators"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getComplete(self, uid):
        postUri = "/{uid}/complete"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__OrgUnitSerDer__()), response)

    def getChildren(self, uid):
        postUri = "/{uid}/_children"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__OrgUnitSerDer__())), response)

    def search(self, query):
        postUri = "/_search"
        __data__ = None
        __encoded__ = None
        from netbluemind.directory.api.OrgUnitQuery import OrgUnitQuery
        from netbluemind.directory.api.OrgUnitQuery import __OrgUnitQuerySerDer__
        __data__ = __OrgUnitQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        return self.handleResult__(serder.ListSerDer(__OrgUnitPathSerDer__()), response)

    def getPath(self, uid):
        postUri = "/{uid}/path"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        return self.handleResult__(__OrgUnitPathSerDer__(), response)

    def create(self, uid, value):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        __data__ = __OrgUnitSerDer__().encode(value)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def listByAdministrator(self, administrator, groups):
        postUri = "/_byAdmin"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(groups)
        __encoded__ = json.dumps(__data__)
        queryParams = {'administrator': administrator}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IOrgUnits_VERSION}, data=__encoded__)
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        return self.handleResult__(serder.ListSerDer(__OrgUnitPathSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailConversationActions_VERSION = "4.1.65141"


class IMailConversationActions(BaseEndpoint):
    def __init__(self, apiKey, url, conversationContainer, replicatedMailboxUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + \
            '/mail_conversation/{conversationContainer}/{replicatedMailboxUid}'
        self.conversationContainer_ = conversationContainer
        self.base = self.base.replace(
            '{conversationContainer}', conversationContainer)
        self.replicatedMailboxUid_ = replicatedMailboxUid
        self.base = self.base.replace(
            '{replicatedMailboxUid}', replicatedMailboxUid)

    def importItems(self, folderDestinationId, mailboxItems):
        postUri = "/importItems/{folderDestinationId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{folderDestinationId}", folderDestinationId)
        from netbluemind.backend.mail.api.flags.ImportMailboxConversationSet import ImportMailboxConversationSet
        from netbluemind.backend.mail.api.flags.ImportMailboxConversationSet import __ImportMailboxConversationSetSerDer__
        __data__ = __ImportMailboxConversationSetSerDer__().encode(mailboxItems)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversationActions_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import ImportMailboxItemsStatus
        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import __ImportMailboxItemsStatusSerDer__
        return self.handleResult__(__ImportMailboxItemsStatusSerDer__(), response)

    def move(self, targetMailboxUid, conversationUids):
        postUri = "/move/{targetMailboxUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{targetMailboxUid}", targetMailboxUid)
        __data__ = serder.ListSerDer(serder.STRING).encode(conversationUids)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversationActions_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemIdentifier import ItemIdentifier
        from netbluemind.core.container.model.ItemIdentifier import __ItemIdentifierSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemIdentifierSerDer__()), response)

    def addFlag(self, flagUpdate):
        postUri = "/_addFlag"
        __data__ = None
        __encoded__ = None
        from netbluemind.backend.mail.api.flags.ConversationFlagUpdate import ConversationFlagUpdate
        from netbluemind.backend.mail.api.flags.ConversationFlagUpdate import __ConversationFlagUpdateSerDer__
        __data__ = __ConversationFlagUpdateSerDer__().encode(flagUpdate)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversationActions_VERSION}, data=__encoded__)
        from netbluemind.core.container.api.Ack import Ack
        from netbluemind.core.container.api.Ack import __AckSerDer__
        return self.handleResult__(__AckSerDer__(), response)

    def multipleDeleteById(self, conversationUids):
        postUri = "/_multipleDelete"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(conversationUids)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversationActions_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def deleteFlag(self, flagUpdate):
        postUri = "/_deleteFlag"
        __data__ = None
        __encoded__ = None
        from netbluemind.backend.mail.api.flags.ConversationFlagUpdate import ConversationFlagUpdate
        from netbluemind.backend.mail.api.flags.ConversationFlagUpdate import __ConversationFlagUpdateSerDer__
        __data__ = __ConversationFlagUpdateSerDer__().encode(flagUpdate)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversationActions_VERSION}, data=__encoded__)
        from netbluemind.core.container.api.Ack import Ack
        from netbluemind.core.container.api.Ack import __AckSerDer__
        return self.handleResult__(__AckSerDer__(), response)

    def copy(self, targetMailboxUid, conversationUids):
        postUri = "/copy/{targetMailboxUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{targetMailboxUid}", targetMailboxUid)
        __data__ = serder.ListSerDer(serder.STRING).encode(conversationUids)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailConversationActions_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemIdentifier import ItemIdentifier
        from netbluemind.core.container.model.ItemIdentifier import __ItemIdentifierSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemIdentifierSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder
from enum import Enum


class ErrorCode(Enum):
    UNKNOWN = 'UNKNOWN'
    PERMISSION_DENIED = 'PERMISSION_DENIED'
    FAILURE = 'FAILURE'
    INVALID_ID = 'INVALID_ID'
    INVALID_PARAMETER = 'INVALID_PARAMETER'
    AUTHENTICATION_FAIL = 'AUTHENTICATION_FAIL'
    SQL_ERROR = 'SQL_ERROR'
    NOT_FOUND = 'NOT_FOUND'
    ALREADY_EXISTS = 'ALREADY_EXISTS'
    FORBIDDEN = 'FORBIDDEN'
    ENTITY_TOO_LARGE = 'ENTITY_TOO_LARGE'
    INVALID_QUERY = 'INVALID_QUERY'
    INVALID_XML_RECEIVED = 'INVALID_XML_RECEIVED'
    CHILD_GROUP_MUST_EXIST = 'CHILD_GROUP_MUST_EXIST'
    CANT_DELETE_MYSELF = 'CANT_DELETE_MYSELF'
    DELEGATION_RESTRICTION = 'DELEGATION_RESTRICTION'
    INVALID_PASSWORD = 'INVALID_PASSWORD'
    LOGIN_ALREADY_USED = 'LOGIN_ALREADY_USED'
    INVALID_LOGIN = 'INVALID_LOGIN'
    EMPTY_LASTNAME = 'EMPTY_LASTNAME'
    EMPTY_VACATION_MESSAGE = 'EMPTY_VACATION_MESSAGE'
    VACATION_WITHOUT_MAILBOX = 'VACATION_WITHOUT_MAILBOX'
    FORWARDING_WITHOUT_MAILBOX = 'FORWARDING_WITHOUT_MAILBOX'
    FORWARDING_INVALID_EMAIL = 'FORWARDING_INVALID_EMAIL'
    INVALID_MAIL_SERVER = 'INVALID_MAIL_SERVER'
    INVALID_GROUP_NAME = 'INVALID_GROUP_NAME'
    FORWARDING_TO_OWN_MAILBOX = 'FORWARDING_TO_OWN_MAILBOX'
    SAME_PARENT_AND_CHILD_GROUP = 'SAME_PARENT_AND_CHILD_GROUP'
    INCLUSION_GROUP_LOOP = 'INCLUSION_GROUP_LOOP'
    EMAIL_ALREADY_USED = 'EMAIL_ALREADY_USED'
    INVALID_EMAIL = 'INVALID_EMAIL'
    MAIL_QUOTA_OVER_DOMAIN_LIMIT = 'MAIL_QUOTA_OVER_DOMAIN_LIMIT'
    NOT_GLOBAL_ADMIN = 'NOT_GLOBAL_ADMIN'
    DOMAIN_NAME_ALREADY_USED = 'DOMAIN_NAME_ALREADY_USED'
    INVALID_MAILSHARE_NAME = 'INVALID_MAILSHARE_NAME'
    INVALID_RESOURCE_NAME = 'INVALID_RESOURCE_NAME'
    OLD_PASSWORD_WRONG = 'OLD_PASSWORD_WRONG'
    OLD_PASSWORD_SAME_AS_NEW = 'OLD_PASSWORD_SAME_AS_NEW'
    IP_ADDRESS_ALREADY_USED = 'IP_ADDRESS_ALREADY_USED'
    MBOX_RENAME_FAILED = 'MBOX_RENAME_FAILED'
    INVALID_HOST_NAME = 'INVALID_HOST_NAME'
    EMPTY_EVENT_TITLE = 'EMPTY_EVENT_TITLE'
    NO_DURATION_EVENT = 'NO_DURATION_EVENT'
    NO_EVENT_DATE = 'NO_EVENT_DATE'
    NO_EVENT_TYPE = 'NO_EVENT_TYPE'
    EVENT_PRIVACY_INVALID = 'EVENT_PRIVACY_INVALID'
    EVENT_ERROR = 'EVENT_ERROR'
    CALENDAR_AUTHORISATION_ERROR = 'CALENDAR_AUTHORISATION_ERROR'
    CONTACT_DOMAIN_FORBIDDEN = 'CONTACT_DOMAIN_FORBIDDEN'
    EVENT_ENDREPEAT_PRIOR_TO_EVENT_DATE = 'EVENT_ENDREPEAT_PRIOR_TO_EVENT_DATE'
    INVALID_DOMAIN_NAME = 'INVALID_DOMAIN_NAME'
    GROUP_NAME_ALREADY_USED = 'GROUP_NAME_ALREADY_USED'
    INVALID_VACATION_RANGE = 'INVALID_VACATION_RANGE'
    EMPTY_DLIST_LABEL = 'EMPTY_DLIST_LABEL'
    EMPTY_DLIST_FOLDER = 'EMPTY_DLIST_FOLDER'
    DLIST_LOOP = 'DLIST_LOOP'
    CANT_UPDATE_ACL_IMPLICIT_RIGHTS = 'CANT_UPDATE_ACL_IMPLICIT_RIGHTS'
    USER_SPLIT_REQUIRES_SPLIT_DOMAIN = 'USER_SPLIT_REQUIRES_SPLIT_DOMAIN'
    SLAVE_RELAY_REQUIRES_SPLIT_DOMAIN = 'SLAVE_RELAY_REQUIRES_SPLIT_DOMAIN'
    INVALID_USER_LDAP_FILTER = 'INVALID_USER_LDAP_FILTER'
    SEC_GROUP_RM = 'SEC_GROUP_RM'
    NOT_IN_GLOBAL_DOMAIN = 'NOT_IN_GLOBAL_DOMAIN'
    NO_BACKUP_SERVER_FOUND = 'NO_BACKUP_SERVER_FOUND'
    OPERATION_ALREADY_RUNNING = 'OPERATION_ALREADY_RUNNING'
    INVALID_AD_HOST_NAME = 'INVALID_AD_HOST_NAME'
    JOB_FINISHED = 'JOB_FINISHED'
    INVALID_LICENSE = 'INVALID_LICENSE'
    HSM_MISSING_POLICY = 'HSM_MISSING_POLICY'
    INCOMPATIBLE_SMTP_TAGS = 'INCOMPATIBLE_SMTP_TAGS'
    INVALID_MAILBOX_NAME = 'INVALID_MAILBOX_NAME'
    TAG_ALREADY_EXIST = 'TAG_ALREADY_EXIST'
    INVALID_LINKED_MAILSHARE = 'INVALID_LINKED_MAILSHARE'
    MAILSHARE_GROUP_LINKED = 'MAILSHARE_GROUP_LINKED'
    SERVER_NOT_FOUND = 'SERVER_NOT_FOUND'
    DEPRECATED = 'DEPRECATED'
    INVALID_GROUP_MEMBER = 'INVALID_GROUP_MEMBER'
    EMPTY_EVENT_ATTACHMENT_VALUE = 'EMPTY_EVENT_ATTACHMENT_VALUE'
    TIMEOUT = 'TIMEOUT'
    VERSION_HAS_CHANGED = 'VERSION_HAS_CHANGED'
    MULTIPLE_EVENT_COUNTERS = 'MULTIPLE_EVENT_COUNTERS'
    EVENT_ACCEPTS_NO_COUNTERS = 'EVENT_ACCEPTS_NO_COUNTERS'
    EVENT_WEEKDAY_INVALID = 'EVENT_WEEKDAY_INVALID'
    EVENT_DUPLICATED_RECURID = 'EVENT_DUPLICATED_RECURID'
    MAX_ITEM_COUNT = 'MAX_ITEM_COUNT'


class __ErrorCodeSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ErrorCode[value]
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = value.value
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IDomains_VERSION = "4.1.65141"


class IDomains(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/domains'

    def all(self):
        postUri = ""
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DomainSerDer__())), response)

    def findByNameOrAliases(self, name):
        postUri = "/_lookup"
        __data__ = None
        __encoded__ = None
        queryParams = {'name': name}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__DomainSerDer__()), response)

    def setAliases(self, uid, aliases):
        postUri = "/{uid}/_aliases"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.SetSerDer(serder.STRING).encode(aliases)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def deleteDomainItems(self, uid):
        postUri = "/{uid}/_items"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def update(self, uid, domain):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        __data__ = __DomainSerDer__().encode(domain)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def get(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__DomainSerDer__()), response)

    def create(self, uid, domain):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        __data__ = __DomainSerDer__().encode(domain)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setRoles(self, uid, roles):
        postUri = "/{uid}/roles"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setDefaultAlias(self, uid, defaultAlias):
        postUri = "/{uid}/_default_alias"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.STRING.encode(defaultAlias)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getRoles(self, uid):
        postUri = "/{uid}/roles"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDomains_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class Recipient:
    def __init__(self):
        self.email = None
        self.name = None
        self.addressType = None
        self.recipientType = None
        pass


class __RecipientSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = Recipient()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        emailValue = value['email']
        instance.email = serder.STRING.parse(emailValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        from netbluemind.mailflow.common.api.RecipientAddressType import RecipientAddressType
        from netbluemind.mailflow.common.api.RecipientAddressType import __RecipientAddressTypeSerDer__
        addressTypeValue = value['addressType']
        instance.addressType = __RecipientAddressTypeSerDer__().parse(addressTypeValue)
        from netbluemind.mailflow.common.api.RecipientRecipientType import RecipientRecipientType
        from netbluemind.mailflow.common.api.RecipientRecipientType import __RecipientRecipientTypeSerDer__
        recipientTypeValue = value['recipientType']
        instance.recipientType = __RecipientRecipientTypeSerDer__().parse(recipientTypeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        emailValue = value.email
        instance["email"] = serder.STRING.encode(emailValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        from netbluemind.mailflow.common.api.RecipientAddressType import RecipientAddressType
        from netbluemind.mailflow.common.api.RecipientAddressType import __RecipientAddressTypeSerDer__
        addressTypeValue = value.addressType
        instance["addressType"] = __RecipientAddressTypeSerDer__().encode(
            addressTypeValue)
        from netbluemind.mailflow.common.api.RecipientRecipientType import RecipientRecipientType
        from netbluemind.mailflow.common.api.RecipientRecipientType import __RecipientRecipientTypeSerDer__
        recipientTypeValue = value.recipientType
        instance["recipientType"] = __RecipientRecipientTypeSerDer__().encode(
            recipientTypeValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IUserSubscription_VERSION = "4.1.65141"


class IUserSubscription(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/users/{domainUid}/subscriptions'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def subscribe(self, subject, subscriptions):
        postUri = "/{subject}/_subscribe"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{subject}", subject)
        from netbluemind.core.container.api.ContainerSubscription import ContainerSubscription
        from netbluemind.core.container.api.ContainerSubscription import __ContainerSubscriptionSerDer__
        __data__ = serder.ListSerDer(
            __ContainerSubscriptionSerDer__()).encode(subscriptions)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def subscribers(self, containerUid):
        postUri = "/_subscribers/{containerUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def unsubscribe(self, subject, containers):
        postUri = "/{subject}/_unsubscribe"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{subject}", subject)
        __data__ = serder.ListSerDer(serder.STRING).encode(containers)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def listSubscriptions(self, subject, type):
        postUri = "/{subject}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{subject}", subject)
        queryParams = {'type': type}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUserSubscription_VERSION}, data=__encoded__)
        from netbluemind.core.container.api.ContainerSubscriptionDescriptor import ContainerSubscriptionDescriptor
        from netbluemind.core.container.api.ContainerSubscriptionDescriptor import __ContainerSubscriptionDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ContainerSubscriptionDescriptorSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ContainerSyncStatus:
    def __init__(self):
        self.syncTokens = None
        self.nextSync = None
        self.lastSync = None
        self.syncStatus = None
        self.syncStatusInfo = None
        pass


class __ContainerSyncStatusSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ContainerSyncStatus()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        syncTokensValue = value['syncTokens']
        instance.syncTokens = serder.MapSerDer(
            serder.STRING).parse(syncTokensValue)
        nextSyncValue = value['nextSync']
        instance.nextSync = serder.LONG.parse(nextSyncValue)
        lastSyncValue = value['lastSync']
        instance.lastSync = serder.DATE.parse(lastSyncValue)
        from netbluemind.core.container.model.ContainerSyncStatusStatus import ContainerSyncStatusStatus
        from netbluemind.core.container.model.ContainerSyncStatusStatus import __ContainerSyncStatusStatusSerDer__
        syncStatusValue = value['syncStatus']
        instance.syncStatus = __ContainerSyncStatusStatusSerDer__().parse(syncStatusValue)
        syncStatusInfoValue = value['syncStatusInfo']
        instance.syncStatusInfo = serder.STRING.parse(syncStatusInfoValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        syncTokensValue = value.syncTokens
        instance["syncTokens"] = serder.MapSerDer(
            serder.STRING).encode(syncTokensValue)
        nextSyncValue = value.nextSync
        instance["nextSync"] = serder.LONG.encode(nextSyncValue)
        lastSyncValue = value.lastSync
        instance["lastSync"] = serder.DATE.encode(lastSyncValue)
        from netbluemind.core.container.model.ContainerSyncStatusStatus import ContainerSyncStatusStatus
        from netbluemind.core.container.model.ContainerSyncStatusStatus import __ContainerSyncStatusStatusSerDer__
        syncStatusValue = value.syncStatus
        instance["syncStatus"] = __ContainerSyncStatusStatusSerDer__().encode(
            syncStatusValue)
        syncStatusInfoValue = value.syncStatusInfo
        instance["syncStatusInfo"] = serder.STRING.encode(syncStatusInfoValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class RoleDescriptor:
    def __init__(self):
        self.id = None
        self.parentRoleId = None
        self.categoryId = None
        self.label = None
        self.description = None
        self.selfPromote = None
        self.dirEntryPromote = None
        self.dirEntryKind = None
        self.siblingRole = None
        self.childsRole = None
        self.visible = None
        self.delegable = None
        self.containerRoles = None
        self.priority = None
        pass


class __RoleDescriptorSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = RoleDescriptor()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        idValue = value['id']
        instance.id = serder.STRING.parse(idValue)
        parentRoleIdValue = value['parentRoleId']
        instance.parentRoleId = serder.STRING.parse(parentRoleIdValue)
        categoryIdValue = value['categoryId']
        instance.categoryId = serder.STRING.parse(categoryIdValue)
        labelValue = value['label']
        instance.label = serder.STRING.parse(labelValue)
        descriptionValue = value['description']
        instance.description = serder.STRING.parse(descriptionValue)
        selfPromoteValue = value['selfPromote']
        instance.selfPromote = serder.BOOLEAN.parse(selfPromoteValue)
        dirEntryPromoteValue = value['dirEntryPromote']
        instance.dirEntryPromote = serder.BOOLEAN.parse(dirEntryPromoteValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        dirEntryKindValue = value['dirEntryKind']
        instance.dirEntryKind = __BaseDirEntryKindSerDer__().parse(dirEntryKindValue)
        siblingRoleValue = value['siblingRole']
        instance.siblingRole = serder.STRING.parse(siblingRoleValue)
        childsRoleValue = value['childsRole']
        instance.childsRole = serder.SetSerDer(
            serder.STRING).parse(childsRoleValue)
        visibleValue = value['visible']
        instance.visible = serder.BOOLEAN.parse(visibleValue)
        delegableValue = value['delegable']
        instance.delegable = serder.BOOLEAN.parse(delegableValue)
        containerRolesValue = value['containerRoles']
        instance.containerRoles = serder.SetSerDer(
            serder.STRING).parse(containerRolesValue)
        priorityValue = value['priority']
        instance.priority = serder.INT.parse(priorityValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        idValue = value.id
        instance["id"] = serder.STRING.encode(idValue)
        parentRoleIdValue = value.parentRoleId
        instance["parentRoleId"] = serder.STRING.encode(parentRoleIdValue)
        categoryIdValue = value.categoryId
        instance["categoryId"] = serder.STRING.encode(categoryIdValue)
        labelValue = value.label
        instance["label"] = serder.STRING.encode(labelValue)
        descriptionValue = value.description
        instance["description"] = serder.STRING.encode(descriptionValue)
        selfPromoteValue = value.selfPromote
        instance["selfPromote"] = serder.BOOLEAN.encode(selfPromoteValue)
        dirEntryPromoteValue = value.dirEntryPromote
        instance["dirEntryPromote"] = serder.BOOLEAN.encode(
            dirEntryPromoteValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        dirEntryKindValue = value.dirEntryKind
        instance["dirEntryKind"] = __BaseDirEntryKindSerDer__().encode(
            dirEntryKindValue)
        siblingRoleValue = value.siblingRole
        instance["siblingRole"] = serder.STRING.encode(siblingRoleValue)
        childsRoleValue = value.childsRole
        instance["childsRole"] = serder.SetSerDer(
            serder.STRING).encode(childsRoleValue)
        visibleValue = value.visible
        instance["visible"] = serder.BOOLEAN.encode(visibleValue)
        delegableValue = value.delegable
        instance["delegable"] = serder.BOOLEAN.encode(delegableValue)
        containerRolesValue = value.containerRoles
        instance["containerRoles"] = serder.SetSerDer(
            serder.STRING).encode(containerRolesValue)
        priorityValue = value.priority
        instance["priority"] = serder.INT.encode(priorityValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailTips:
    def __init__(self):
        self.forRecipient = None
        self.matchingTips = None
        pass


class __MailTipsSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailTips()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.mailflow.common.api.Recipient import Recipient
        from netbluemind.mailflow.common.api.Recipient import __RecipientSerDer__
        forRecipientValue = value['forRecipient']
        instance.forRecipient = __RecipientSerDer__().parse(forRecipientValue)
        from netbluemind.mailmessage.api.MailTip import MailTip
        from netbluemind.mailmessage.api.MailTip import __MailTipSerDer__
        matchingTipsValue = value['matchingTips']
        instance.matchingTips = serder.ListSerDer(
            __MailTipSerDer__()).parse(matchingTipsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.mailflow.common.api.Recipient import Recipient
        from netbluemind.mailflow.common.api.Recipient import __RecipientSerDer__
        forRecipientValue = value.forRecipient
        instance["forRecipient"] = __RecipientSerDer__().encode(
            forRecipientValue)
        from netbluemind.mailmessage.api.MailTip import MailTip
        from netbluemind.mailmessage.api.MailTip import __MailTipSerDer__
        matchingTipsValue = value.matchingTips
        instance["matchingTips"] = serder.ListSerDer(
            __MailTipSerDer__()).encode(matchingTipsValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class SchemaCheckInfo:
    def __init__(self):
        self.server = None
        self.db = None
        self.statements = None
        pass


class __SchemaCheckInfoSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = SchemaCheckInfo()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        serverValue = value['server']
        instance.server = serder.STRING.parse(serverValue)
        dbValue = value['db']
        instance.db = serder.STRING.parse(dbValue)
        statementsValue = value['statements']
        instance.statements = serder.STRING.parse(statementsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        serverValue = value.server
        instance["server"] = serder.STRING.encode(serverValue)
        dbValue = value.db
        instance["db"] = serder.STRING.encode(dbValue)
        statementsValue = value.statements
        instance["statements"] = serder.STRING.encode(statementsValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MessageBody:
    def __init__(self):
        self.guid = None
        self.subject = None
        self.smartAttach = None
        self.date = None
        self.size = None
        self.headers = None
        self.recipients = None
        self.messageId = None
        self.references = None
        self.structure = None
        self.preview = None
        self.bodyVersion = None
        pass


class __MessageBodySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MessageBody()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        guidValue = value['guid']
        instance.guid = serder.STRING.parse(guidValue)
        subjectValue = value['subject']
        instance.subject = serder.STRING.parse(subjectValue)
        smartAttachValue = value['smartAttach']
        instance.smartAttach = serder.BOOLEAN.parse(smartAttachValue)
        dateValue = value['date']
        instance.date = serder.DATE.parse(dateValue)
        sizeValue = value['size']
        instance.size = serder.INT.parse(sizeValue)
        from netbluemind.backend.mail.api.MessageBodyHeader import MessageBodyHeader
        from netbluemind.backend.mail.api.MessageBodyHeader import __MessageBodyHeaderSerDer__
        headersValue = value['headers']
        instance.headers = serder.ListSerDer(
            __MessageBodyHeaderSerDer__()).parse(headersValue)
        from netbluemind.backend.mail.api.MessageBodyRecipient import MessageBodyRecipient
        from netbluemind.backend.mail.api.MessageBodyRecipient import __MessageBodyRecipientSerDer__
        recipientsValue = value['recipients']
        instance.recipients = serder.ListSerDer(
            __MessageBodyRecipientSerDer__()).parse(recipientsValue)
        messageIdValue = value['messageId']
        instance.messageId = serder.STRING.parse(messageIdValue)
        referencesValue = value['references']
        instance.references = serder.ListSerDer(
            serder.STRING).parse(referencesValue)
        from netbluemind.backend.mail.api.MessageBodyPart import MessageBodyPart
        from netbluemind.backend.mail.api.MessageBodyPart import __MessageBodyPartSerDer__
        structureValue = value['structure']
        instance.structure = __MessageBodyPartSerDer__().parse(structureValue)
        previewValue = value['preview']
        instance.preview = serder.STRING.parse(previewValue)
        bodyVersionValue = value['bodyVersion']
        instance.bodyVersion = serder.INT.parse(bodyVersionValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        guidValue = value.guid
        instance["guid"] = serder.STRING.encode(guidValue)
        subjectValue = value.subject
        instance["subject"] = serder.STRING.encode(subjectValue)
        smartAttachValue = value.smartAttach
        instance["smartAttach"] = serder.BOOLEAN.encode(smartAttachValue)
        dateValue = value.date
        instance["date"] = serder.DATE.encode(dateValue)
        sizeValue = value.size
        instance["size"] = serder.INT.encode(sizeValue)
        from netbluemind.backend.mail.api.MessageBodyHeader import MessageBodyHeader
        from netbluemind.backend.mail.api.MessageBodyHeader import __MessageBodyHeaderSerDer__
        headersValue = value.headers
        instance["headers"] = serder.ListSerDer(
            __MessageBodyHeaderSerDer__()).encode(headersValue)
        from netbluemind.backend.mail.api.MessageBodyRecipient import MessageBodyRecipient
        from netbluemind.backend.mail.api.MessageBodyRecipient import __MessageBodyRecipientSerDer__
        recipientsValue = value.recipients
        instance["recipients"] = serder.ListSerDer(
            __MessageBodyRecipientSerDer__()).encode(recipientsValue)
        messageIdValue = value.messageId
        instance["messageId"] = serder.STRING.encode(messageIdValue)
        referencesValue = value.references
        instance["references"] = serder.ListSerDer(
            serder.STRING).encode(referencesValue)
        from netbluemind.backend.mail.api.MessageBodyPart import MessageBodyPart
        from netbluemind.backend.mail.api.MessageBodyPart import __MessageBodyPartSerDer__
        structureValue = value.structure
        instance["structure"] = __MessageBodyPartSerDer__().encode(
            structureValue)
        previewValue = value.preview
        instance["preview"] = serder.STRING.encode(previewValue)
        bodyVersionValue = value.bodyVersion
        instance["bodyVersion"] = serder.INT.encode(bodyVersionValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IInstantMessaging_VERSION = "4.1.65141"


class IInstantMessaging(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/im'

    def getLastMessagesBetween(self, user1, user2, messagesCount):
        postUri = "/_getLastMessagesBetween"
        __data__ = None
        __encoded__ = None
        queryParams = {'user1': user1, 'user2': user2,
                       'messagesCount': messagesCount}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstantMessaging_VERSION}, data=__encoded__)
        from netbluemind.im.api.IMMessage import IMMessage
        from netbluemind.im.api.IMMessage import __IMMessageSerDer__
        return self.handleResult__(serder.ListSerDer(__IMMessageSerDer__()), response)

    def isActiveUser(self, uid):
        postUri = "/_activeUser/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstantMessaging_VERSION}, data=__encoded__)
        return self.handleResult__(serder.BOOLEAN, response)

    def sendGroupChatHistory(self, sender, groupChatId, recipients):
        postUri = "/_sendGroupChatHistory/{groupChatId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{groupChatId}", groupChatId)
        __data__ = serder.ListSerDer(serder.STRING).encode(recipients)
        __encoded__ = json.dumps(__data__)
        queryParams = {'sender': sender}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstantMessaging_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setRoster(self, jabberId, data):
        postUri = "/_setRoster"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(data)
        __encoded__ = json.dumps(__data__)
        queryParams = {'jabberId': jabberId}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstantMessaging_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getRoster(self, jabberId):
        postUri = "/_getRoster"
        __data__ = None
        __encoded__ = None
        queryParams = {'jabberId': jabberId}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstantMessaging_VERSION}, data=__encoded__)
        return self.handleResult__(serder.STRING, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IHSM_VERSION = "4.1.65141"


class IHSM(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/hsm/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def promoteMultiple(self, promote):
        postUri = "/_massPromote"
        __data__ = None
        __encoded__ = None
        from netbluemind.hsm.api.Promote import Promote
        from netbluemind.hsm.api.Promote import __PromoteSerDer__
        __data__ = serder.ListSerDer(__PromoteSerDer__()).encode(promote)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IHSM_VERSION}, data=__encoded__)
        from netbluemind.hsm.api.TierChangeResult import TierChangeResult
        from netbluemind.hsm.api.TierChangeResult import __TierChangeResultSerDer__
        return self.handleResult__(serder.ListSerDer(__TierChangeResultSerDer__()), response)

    def getSize(self, mailboxUid):
        postUri = "/_getSize/{mailboxUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IHSM_VERSION}, data=__encoded__)
        return self.handleResult__(serder.DOUBLE, response)

    def fetch(self, mailboxUid, hsmId):
        postUri = "/_fetch/{mailboxUid}/{hsmId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        postUri = postUri.replace("{hsmId}", hsmId)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IHSM_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def copy(self, sourceMailboxUid, destMailboxUid, hsmIds):
        postUri = "/_copy/{sourceMailboxUid}/{destMailboxUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{sourceMailboxUid}", sourceMailboxUid)
        postUri = postUri.replace("{destMailboxUid}", destMailboxUid)
        __data__ = serder.ListSerDer(serder.STRING).encode(hsmIds)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IHSM_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailFilterVacation:
    def __init__(self):
        self.enabled = None
        self.start = None
        self.end = None
        self.text = None
        self.textHtml = None
        self.subject = None
        pass


class __MailFilterVacationSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterVacation()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        enabledValue = value['enabled']
        instance.enabled = serder.BOOLEAN.parse(enabledValue)
        startValue = value['start']
        instance.start = serder.DATE.parse(startValue)
        endValue = value['end']
        instance.end = serder.DATE.parse(endValue)
        textValue = value['text']
        instance.text = serder.STRING.parse(textValue)
        textHtmlValue = value['textHtml']
        instance.textHtml = serder.STRING.parse(textHtmlValue)
        subjectValue = value['subject']
        instance.subject = serder.STRING.parse(subjectValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        enabledValue = value.enabled
        instance["enabled"] = serder.BOOLEAN.encode(enabledValue)
        startValue = value.start
        instance["start"] = serder.DATE.encode(startValue)
        endValue = value.end
        instance["end"] = serder.DATE.encode(endValue)
        textValue = value.text
        instance["text"] = serder.STRING.encode(textValue)
        textHtmlValue = value.textHtml
        instance["textHtml"] = serder.STRING.encode(textHtmlValue)
        subjectValue = value.subject
        instance["subject"] = serder.STRING.encode(subjectValue)
        return instance
